@@ -57,10 +57,12 @@ DEFAULT_PLAN_ENV_KEY = 'parameter_defaults'
 DEFAULT_TEMPLATES_PATH = '/usr/share/openstack-tripleo-heat-templates/'
 
 #: The path to the base directory of tripleo-validations
-DEFAULT_VALIDATIONS_BASEDIR = '/usr/share/openstack-tripleo-validations'
+DEFAULT_VALIDATIONS_BASEDIR = "/usr/share/ansible"
+DEFAULT_VALIDATIONS_LEGACY_BASEDIR = "/usr/share/openstack-tripleo-validations"
 
 # The path to the tripleo validations installed on the undercloud
-DEFAULT_VALIDATIONS_PATH = DEFAULT_VALIDATIONS_BASEDIR + '/playbooks/'
+DEFAULT_VALIDATIONS_PATH = "{}/validation-playbooks/".format(
+    DEFAULT_VALIDATIONS_BASEDIR)
 
 # The path to the local CA certificate installed on the undercloud
 LOCAL_CACERT_PATH = '/etc/pki/ca-trust/source/anchors/cm-local-ca.pem'
@@ -81,12 +83,9 @@ PASSWORD_PARAMETER_NAMES = (
     'BarbicanSimpleCryptoKek',
     'CeilometerMeteringSecret',
     'CeilometerPassword',
-    'CephAdminKey',
     'CephClientKey',
     'CephClusterFSID',
-    'CephMdsKey',
     'CephManilaClientKey',
-    'CephMonKey',
     'CephRgwKey',
     'CephGrafanaAdminPassword',
     'CephDashboardAdminPassword',
@@ -156,6 +155,11 @@ DO_NOT_ROTATE_LIST = (
     'KeystoneFernetKey0',
     'KeystoneFernetKey1',
     'KeystoneFernetKeys',
+    'CephClientKey',
+    'CephClusterFSID',
+    'CephManilaClientKey',
+    'CephRgwKey',
+    'HeatAuthEncryptionKey',
 )
 
 PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
@@ -207,7 +211,9 @@ TRIPLEO_NETWORK_CONFIG_RESOURCE = 'NetworkConfig'
 
 HOST_NETWORK = 'ctlplane'
 
-EXTERNAL_TASKS = ['external_deploy_tasks']
+# The key is different in RoleConfig than in RoleData, so we need both so they
+# are correctly found.
+EXTERNAL_TASKS = ['external_deploy_tasks', 'external_deploy_steps_tasks']
 
 ANSIBLE_ERRORS_FILE = 'ansible-errors.json'
 
@@ -219,4 +225,11 @@ EXCLUSIVE_NEUTRON_DRIVERS = ['ovn', 'openvswitch']
 
 DEFAULT_STEPS_MAX = 6
 
-PER_STEP_TASKS = ['upgrade_tasks', 'deploy_steps_tasks']
+_PER_STEP_TASK_STRICTNESS = [False for i in range(DEFAULT_STEPS_MAX)]
+
+PER_STEP_TASKS = {
+    'upgrade_tasks': _PER_STEP_TASK_STRICTNESS,
+    'deploy_steps_tasks': _PER_STEP_TASK_STRICTNESS,
+    'update_tasks': _PER_STEP_TASK_STRICTNESS,
+    'post_update_tasks': [False, False, False, False]
+}
