@@ -26,7 +26,7 @@ from tripleo_common import constants
 from tripleo_common.utils import parameters
 from tripleo_common.utils import plan as plan_utils
 from tripleo_common.utils import swift as swiftutils
-from tripleo_common.utils import tarball as tarball
+from tripleo_common.utils import tarball
 
 LOG = logging.getLogger(__name__)
 
@@ -64,14 +64,18 @@ class J2SwiftLoader(jinja2.BaseLoader):
 def j2_render_and_put(swift, j2_template, j2_data, yaml_f,
                       container=constants.DEFAULT_CONTAINER_NAME):
 
+    def raise_helper(msg):
+        raise jinja2.exceptions.TemplateError(msg)
+
     # Search for templates relative to the current template path first
     template_base = os.path.dirname(yaml_f)
     j2_loader = J2SwiftLoader(swift, container, template_base)
 
     try:
         # Render the j2 template
-        template = jinja2.Environment(loader=j2_loader).from_string(
-            j2_template)
+        jinja2_env = jinja2.Environment(loader=j2_loader)
+        jinja2_env.globals['raise'] = raise_helper
+        template = jinja2_env.from_string(j2_template)
         r_template = template.render(**j2_data)
     except jinja2.exceptions.TemplateError as ex:
         error_msg = ("Error rendering template %s : %s"
@@ -150,6 +154,10 @@ def process_custom_roles(swift, heat,
         # Allow no networks defined in network_data
         if network_data is None:
             network_data = []
+        # Set internal network index key for each network, network resources
+        # are created with a tag tripleo_net_idx
+        for idx, _ in enumerate(network_data):
+            network_data[idx].update({'idx': idx})
     except swiftexceptions.ClientException:
         # Until t-h-t contains network_data.yaml we tolerate a missing file
         LOG.warning("No %s file found, ignoring"
